@@ -4,9 +4,7 @@ Helper classes to publish metrics
 import logging
 from abc import ABC, abstractmethod
 from datetime import datetime
-from typing import Any, Dict, List, Optional, Union
-
-from typing_extensions import TypedDict
+from typing import Any, Dict, List, Optional, TypedDict, Union
 
 from samtranslator.internal.deprecation_control import deprecated
 
@@ -63,8 +61,8 @@ class CWMetricsPublisher(MetricsPublisher):
         try:
             if metric_data:
                 self.cloudwatch_client.put_metric_data(Namespace=namespace, MetricData=metric_data)
-        except Exception as e:
-            LOG.exception(f"Failed to report {len(metric_data)} metrics", exc_info=e)
+        except Exception:
+            LOG.exception(f"Failed to report {len(metric_data)} metrics")
 
 
 class DummyMetricsPublisher(MetricsPublisher):
