@@ -1,5 +1,7 @@
+from re import search
 from typing import Any, Dict, Optional, Union
-from urllib.parse import urlparse, parse_qs
+from urllib.parse import parse_qs, urlparse
+
 from samtranslator.model.exceptions import InvalidResourceException
 
 
@@ -56,7 +58,7 @@ def construct_image_code_object(image_uri, logical_id, property_name):  # type:
     """
     if not image_uri:
         raise InvalidResourceException(
-            logical_id, "'{}' requires that a image hosted at a registry be specified.".format(property_name)
+            logical_id, f"'{property_name}' requires that a image hosted at a registry be specified."
         )
 
     return {"ImageUri": image_uri}
@@ -78,21 +80,31 @@ def construct_s3_location_object(
         if not location_uri.get("Bucket") or not location_uri.get("Key"):
             # location_uri is a dictionary but does not contain Bucket or Key property
             raise InvalidResourceException(
-                logical_id, "'{}' requires Bucket and Key properties to be specified.".format(property_name)
+                logical_id, f"'{property_name}' requires Bucket and Key properties to be specified."
             )
 
         s3_pointer = location_uri
 
     else:
+        # SSM Pattern found here https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/dynamic-references.html
+        ssm_pattern = r"{{resolve:(ssm|ssm-secure|secretsmanager):[a-zA-Z0-9_.\-/]+(:\d+)?}}"
+        match = search(ssm_pattern, location_uri)
+        if match and match.group(0) and "/" in match.group(0):
+            raise InvalidResourceException(
+                logical_id,
+                f"Unsupported dynamic reference detected in '{property_name}'. Please "
+                "consider using alternative 'FunctionCode' object format.",
+            )
+
         # location_uri is NOT a dictionary. Parse it as a string
         _s3_pointer = parse_s3_uri(location_uri)
 
         if _s3_pointer is None:
             raise InvalidResourceException(
                 logical_id,
-                "'{}' is not a valid S3 Uri of the form "
+                f"'{property_name}' is not a valid S3 Uri of the form "
                 "'s3://bucket/key' with optional versionId query "
-                "parameter.".format(property_name),
+                "parameter.",
             )
         s3_pointer = _s3_pointer
 
